package it.univr.prog.bioinfo.pizzeria;

import java.util.List;

/**
 * Classe oggetto che rappresenta un ordine.
 * 
 * @author Damiano Macedonio
 * @version 2.0
 */

public class Ordine {
	
	/**
	 * Lista contenente le pizze che costituiscono l'ordine.
	 */
	private List<Pizza> pizze;
	
	
	/**
	 * Costruisce un ordine con le pizze date
	 * @param pizze lista delle pizze da includere nell'ordine
	 */
	public Ordine(List<Pizza> pizze) {
		this.pizze = pizze;
	}
	
	/**
	 * Ritorna il prezzo totale dell'ordine. 
	 *
	 * @return  prezzo totale dell'ordine
	 */
	public double getTotale() {
		double totale = 0;
		for (Pizza p : pizze)
			totale += p.getPrezzo();
		return totale;
	}

	/**
	 * Aggiunge una pizza all'ordine.
	 * 
	 * @param p pizza da aggiungere all'ordine 
	 * 
	 */
	public void aggiungiPizza(Pizza p){
		pizze.add(p);
	}
	
	/**
	 * Ritorna una descrizione testuale dell'ordine. 
	 *
	 * @return  descrizione testuale dell'ordine
	 */
	public String toString(){
		String str ="";
		for(Pizza p : pizze)
			str += p.getNome() + " " + p.getPrezzo() + "\n";
		str += "\t Totale: " + getTotale();
		return str + "\n";
	}
}